<?php
namespace Controller;

use Service\GeralService;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;

class CRMCrud extends TeknisaCrud {
    protected $dataSourceName = '';

    protected $primaryKey = '';
    protected $CDCONTADOR = null;

    protected $parameterBagColumns = array();

    protected $parameterBag;
    protected $geralService;

    public function __construct (Manager $dataSourceManager, GeralService $geralService, ParameterBag $parameterBag) {
        $this->geralService = $geralService;
        $this->parameterBag = $parameterBag;
        parent::__construct($dataSourceManager);
    }

    public function remove($request, DTO\Response $response) {
    	if($request instanceof DTO\Request\DataSet) parent::delete($request, $response);
    	else if($request instanceof DTO\Request\Row) {
    		parent::delete($this->getDataSetFromRow($request), $response);
    	}
    }

	public function getDataSetFromRow(DTO\Request\Row $row) {
		$dataSet = new DataSet($this->dataSourceName, array($row->getRow()));
		return new DTO\Request\DataSet($dataSet, $row->getMethod(), $row->getRoutePath(), $row->getUserId());
	}

    protected function populateParameterBag(FilterCriteria $filterCriteria) {
        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }

        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );

        return $newFilterCriteria;
    }
    
    protected function processConditionValue($condition) {
        return $condition['value'];
    }

    public function save(DTO\Request\DataSet $request, DTO\Response $response) {
    	foreach($request->getDataSet()->getRows() as $row) {
            if(!array_key_exists('CDOPERULTATU', $row)) $row['CDOPERULTATU'] = null;
            if(!array_key_exists('NRORGULTATU', $row)) $row['NRORGULTATU'] = null;
            if(!array_key_exists('DTULTATU', $row)) $row['DTULTATU'] = null;
            if(!array_key_exists('IDATIVO', $row)) $row['IDATIVO'] = 'S';
           
            if(!array_key_exists('NRORG', $row)) $row['NRORG'] = 1;

            if($row['__is_new']){

                if(isset($this->CDCONTADOR) && isset($this->primaryKey))
	                $row[$this->primaryKey] = $this->geralService->getNextId($this->CDCONTADOR, $row['NRORG']);

                date_default_timezone_set('America/Sao_Paulo');
                $row['DTINCLUSAO'] = date('d/m/Y');
            } else {
                date_default_timezone_set('America/Sao_Paulo');
                $row['DTULTATU'] = date('d/m/Y');
            }
        }
    	parent::save($request, $response);
    }

    public function search(DTO\Request\Filter $request, DTO\Response $response) {
        $filterCriteria = $request->getFilterCriteria();
        $filterCriteria->setDataSourceName($this->dataSourceName);
        $newFilterCriteria = $this->populateParameterBag($filterCriteria);
        $dataSet = $this->dataSourceManager->findBy($newFilterCriteria);
        $response->addDataSet($dataSet);
    }
}