<?php
namespace Teknisa\CRM\Controller;

use Teknisa\CRM\Controller\TeknisaCrud;
use Teknisa\Model\Util\NovoCodigo;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;

class crmCadastroSLA extends TeknisaCrud {
    
    protected $dataSourceName = 'crm_sla';
    
    protected $entityManager;
    protected $connection;
    protected $newCode;
    protected $environment;

    
    public function __construct ($crudService, $parameterBag, $entityManager, $newCode, $environment)
    {
        $this->entityManager = $entityManager;
        $this->newCode       = $newCode;
        $this->connection    = $entityManager->getConnection();
        $this->environment   = $environment;

        parent::__construct($crudService, $parameterBag);
    }
    
    
    public function vincular(Request $request, Response $response) {
        $dataset = $request->getDataSet()->getRows();
        foreach($dataset[0]['rows'] as $row) {
            $row['NRSLAPARCNEGOCIO'] =  NovoCodigo::geraCodigo($this->environment->getNrOrgTrab(), "CRM_SLAPARCNEGOCIO", 1, 10, false, false);
            
            $insertVinculo = "INSERT INTO CRM_SLAPARCNEGOCIO (NRORG, NRSLAPARCNEGOCIO, NRPARCNEGOCIO, NRSEQSLA)
             VALUES (:NRORG,
                     :NRSLAPARCNEGOCIO,
                     :NRPARCNEGOCIO,
                     :NRSEQSLA)";
                    
            $params = array
            (
                "NRORG"                 => $row["NRORG"],
                "NRSLAPARCNEGOCIO"      => $row["NRSLAPARCNEGOCIO"],
                "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
                "NRSEQSLA"              => $dataset[0]['nrseqsla']
                );
    
            try
            {
                $std = $this->entityManager->getConnection()->prepare($insertVinculo);
                $std->execute($params);
            }
            catch(\Exception $e)
            {
                $response->setError(new Error($e->getMessage(), $e->getCode()));
            };
        }
    }

    public function deleteProduto($request, $response) {
             $row = $request->getRow();
            
            $deleteSLAProduto = "DELETE FROM CRM_SLAPRODPARCNEG
                        WHERE NRSLAPARCNEGOCIO = :NRSLAPARCNEGOCIO
                          AND NRORG         = :NRORG";
    
            $params = array
            (
                "NRSLAPARCNEGOCIO"  => $row["NRSLAPARCNEGOCIO"],
                "NRORG"             => $row["NRORG"]
            );
    
            try
            {
                $std = $this->connection->prepare($deleteSLAProduto);
                $std->execute($params);
            }catch (\Exception $e)
            {
                throw $e;
            }
    }

    public function desvincular($request, $response){
        self::deleteProduto($request, $response);
        $row = $request->getRow();
        
        $deleteSLAParcnegocio = "DELETE FROM CRM_SLAPARCNEGOCIO
                    WHERE NRSLAPARCNEGOCIO = :NRSLAPARCNEGOCIO
                      AND NRORG            = :NRORG";

        $params = array
        (
            "NRSLAPARCNEGOCIO"  => $row["NRSLAPARCNEGOCIO"],
            "NRORG"             => $row["NRORG"]
        );

        try
        {
            $std = $this->connection->prepare($deleteSLAParcnegocio);
            $std->execute($params);
        }catch (\Exception $e)
        {
            throw $e;
        }
    
    }
    
    public function saveSlaPrioridade(Request $request, Response $response){
        $dataset = $request->getDataSet()->getRows();
        
        foreach($dataset[0]['rows'] as $row) {
            
            $row['NRSLAPRIORIDADE'] = NovoCodigo::geraCodigo($this->environment->getNrOrgTrab(), "CRM_SLAPRIORIDADE", 1, 10, false, false);

            
            $insertVinculo = "INSERT INTO CRM_SLAPRIORIDADE (NRORG, NRSLAPRIORIDADE, NRPRIORIDADE, NRSEQSLA, NRHORATRAB, NRTEMPORESPSLA, NRTEMPORESPREAL, IDTPRESPONDER, NRTEMPOSOLUSLA, NRTEMPOSOLUREAL, IDTPRESOLVER, IDENVIAREMAIL, DSTPREAL)
             VALUES (:NRORG,
                     :NRSLAPRIORIDADE,
                     :NRPRIORIDADE,
                     :NRSEQSLA,
                     :NRHORATRAB,
                     :NRTEMPORESPSLA,
                     :NRTEMPORESPREAL,
                     :IDTPRESPONDER,
                     :NRTEMPOSOLUSLA,
                     :NRTEMPOSOLUREAL,
                     :IDTPRESOLVER,
                     :IDENVIAREMAIL,
                     :DSTPREAL)";  
                    
            $params = array
            (
                "NRORG"                 => $row["NRORG"],
                "NRSLAPRIORIDADE"       => $row["NRSLAPRIORIDADE"],
                "NRPRIORIDADE"          => $row["DSPRIORIDADE"],
                "NRSEQSLA"              => $dataset[0]['SLA']['NRSEQSLA'],
                "NRHORATRAB"            => $row["NRHORATRAB"],
                "NRTEMPORESPSLA"        => $row["RESPONDER"],
                "NRTEMPORESPREAL"       => $row["RESPONDEREAL"],
                "IDTPRESPONDER"         => $row["RESPONDER_OPTION"],
                "NRTEMPOSOLUSLA"        => $row["RESOLVER"],
                "NRTEMPOSOLUREAL"       => $row["RESOLVEREAL"],
                "IDTPRESOLVER"          => $row["RESOLVER_OPTION"],
                "IDENVIAREMAIL"         => $row["MANDAEMAIL"],
                "DSTPREAL"              => $row["AVISO"]
                );
    
            try
            {
                $std = $this->entityManager->getConnection()->prepare($insertVinculo);
                $std->execute($params);
            }
            catch(\Exception $e)
            {
                $response->setError(new Error($e->getMessage(), $e->getCode()));
            };
        }
        
    }
    
    public function prioridadeSLA(Request $request, Response $response){
        $dataset = $request->getDataSet()->getRows();
        $dataset[0]['SLA']['NRSEQSLA'] =  NovoCodigo::geraCodigo($this->environment->getNrOrgTrab(), "CRM_SLA", 1, 10, false, false);
        
        $row = $request->getDataSet()->getRows()[0]["SLA"];
        
            $insertSLA = "INSERT INTO CRM_SLA (NRSEQSLA, NMSLA, DSSLA)
             VALUES (:NRSEQSLA,
                     :NMSLA,
                     :DSSLA)";
                    
            $params = array
            (
                     "NRSEQSLA"     => $row["NRSEQSLA"],
                     "NMSLA"        => $row["NMSLA"],
                     "DSSLA"        => $row["DSSLA"]
                );
    
            try
            {
                $std = $this->entityManager->getConnection()->prepare($insertSLA);
                $std->execute($params);
            }
            catch(\Exception $e)
            {
                $response->setError(new Error($e->getMessage(), $e->getCode()));
            };
       
       
        self::saveSlaPrioridade($request, $response);
    }
    
    public function SLAPrioridadeDelete(Request $request, Response $response){
        $row = $request->getRow();
        
        $deleteSLAPrioridade = "DELETE FROM CRM_SLAPRIORIDADE
                                    WHERE NRSEQSLA  = :NRSEQSLA
                                    AND NRORG       = :NRORG";
        $params = array
                (
                    "NRSEQSLA"     => $row["NRSEQSLA"],
                    "NRORG"        => $row["NRORG"]
                );
        
                try
                {
                    $std = $this->connection->prepare($deleteSLAPrioridade);
                    $std->execute($params);
                }catch (\Exception $e)
                {
                    throw $e;
                }
        
        
    }
    
    public function SLAParcnegocioDelete(Request $request, Response $response){
        $row = $request->getRow();
        $response->setError(new Error($e->getMessage(), $e->getCode()));
        $deleteSLAParceiro = "DELETE FROM CRM_SLAPARCNEGOCIO
                                    WHERE NRSEQSLA  = :NRSEQSLA
                                    AND NRORG       = :NRORG";
        $params = array
        (
            "NRSEQSLA"     => $row["NRSEQSLA"],
            "NRORG"        => $row["NRORG"]
        );

        try
        {
            $std = $this->connection->prepare($deleteSLAParceiro);
            $std->execute($params);
        }catch (\Exception $e)
        {
            throw $e;
        }
    }
    
    public function inativaSLA($request, $response){
        $row = $request->getRow();
        
        
           $inativaSLA = "UPDATE CRM_SLA
                      SET   IDATIVO   = :IDATIVO
                    WHERE NRSEQSLA          = :NRSEQSLA
                      AND NRORG             = :NRORG";
                    
            $params = array
            (
                "NRORG"     => $row["NRORG"],
                "NRSEQSLA"  => $row["NRSEQSLA"],
                "IDATIVO"   => "N"
                
            );
    
           try {
                $std = $this->connection->prepare($inativaSLA);
                $std->execute($params);
            }
            catch (\Exception $e) {
                throw $e;
            };
     }
     
    public function prioridadeUpdate(Request $request, Response $response){
        $rowsPRIORIDADES = $request->getDataSet()->getRows()[0]['prioridade'];
        
        foreach($rowsPRIORIDADES as $rowsPRIORIDADE) {
            
            $updateSLAPRIORIDADE = "UPDATE CRM_SLAPRIORIDADE
                      SET   NRTEMPOSOLUSLA  = :NRTEMPOSOLUSLA,
                            NRTEMPORESPSLA  = :NRTEMPORESPSLA,
                            IDENVIAREMAIL   = :IDENVIAREMAIL,
                            NRHORATRAB      = :NRHORATRAB,
                            IDTPRESOLVER    = :IDTPRESOLVER,
                            IDTPRESPONDER   = :IDTPRESPONDER,
                            DSTPREAL        = :DSTPREAL
                    WHERE NRSEQSLA          = :NRSEQSLA
                      AND NRORG             = :NRORG
                      AND NRSLAPRIORIDADE   = :NRSLAPRIORIDADE";
                    
            $params = array
            (
                "NRORG"                 => $rowsPRIORIDADE["NRORG"],
                "NRSEQSLA"              => $rowsPRIORIDADE["NRSEQSLA"],
                "NRSLAPRIORIDADE"       => $rowsPRIORIDADE["NRSLAPRIORIDADE"],
                "NRTEMPOSOLUSLA"        => $rowsPRIORIDADE["RESOLVER"],
                "NRTEMPORESPSLA"        => $rowsPRIORIDADE["RESPONDER"],
                "IDENVIAREMAIL"         => $rowsPRIORIDADE["MANDAEMAIL"],
                "NRHORATRAB"            => $rowsPRIORIDADE["NRHORATRAB"],
                "IDTPRESOLVER"          => $rowsPRIORIDADE["TPRESOLVER"],
                "IDTPRESPONDER"         => $rowsPRIORIDADE["TPRESPONDER"],
                "DSTPREAL"              => $rowsPRIORIDADE["AVISO"]
                
            );
    
           try {
                $std = $this->connection->prepare($updateSLAPRIORIDADE);
                $std->execute($params);
            }
            catch (\Exception $e) {
                throw $e;
            }
        }
        
    }
     
    public function slaUpdate(Request $request, Response $response){
        $rowSLA = $request->getDataSet()->getRows()[0]['sla'];

        self::prioridadeUpdate($request, $response);

        $updateSLA = "UPDATE CRM_SLA
                      SET NMSLA     = :NMSLA,
                          DSSLA     = :DSSLA
                    WHERE NRSEQSLA = :NRSEQSLA
                      AND NRORG      = :NRORG";

        $params = array
        (
            "NRORG"     => $rowSLA["NRORG"],
            "NRSEQSLA"  => $rowSLA["NRSEQSLA"],
            "NMSLA"     => $rowSLA["NMSLA"],
            "DSSLA"     => $rowSLA["DSSLA"]
        );

        try {
            $std = $this->connection->prepare($updateSLA);
            $std->execute($params);
        }
        catch (\Exception $e) {
            throw $e;
        }
     
        
    } 
    
    public function parcnegocioSlaProduto(Request $request, Response $response) {
        $dataset = $request->getDataSet()->getRows();
        foreach($dataset[0]['rows'] as $row) {

            $row['NRSLAPRODPARCNEG'] =  NovoCodigo::geraCodigo($this->environment->getNrOrgTrab(), "CRM_SLAPRODPARCNEG", 1, 10, false, false);
            
            $insertVinculo = "INSERT INTO CRM_SLAPRODPARCNEG (NRORG, NRSLAPRODPARCNEG, NRARVOREPROD, NRTPARVPROD, CDPRODUTO, NRSLAPARCNEGOCIO)
             VALUES (:NRORG,
                     :NRSLAPRODPARCNEG,
                     :NRARVOREPROD,
                     :NRTPARVPROD,
                     :CDPRODUTO,
                     :NRSLAPARCNEGOCIO)";
                    
            $params = array
            (
                "NRORG"                 => $row["NRORG"],
                "NRSLAPRODPARCNEG"      => (int)$row['NRSLAPRODPARCNEG'],
                "NRARVOREPROD"          => $row["NRARVOREPROD"],
                "NRTPARVPROD"           => $row["NRTPARVPROD"],
                "CDPRODUTO"             => $row["ID"],
                "NRSLAPARCNEGOCIO"      => $dataset[0]['nrslaparcnegocio']
                );
    
            try
            {
                $std = $this->entityManager->getConnection()->prepare($insertVinculo);
                $std->execute($params);
            }
            catch(\Exception $e)
            {
                $response->setError(new Error($e->getMessage(), $e->getCode()));
            };
        }
    }
}





