 /* Sistemas Integrados TEKNISA
   Planejamento Alimentao Industrial

Nome: SERVICOS_TRANSPORTADOS

Descrio:
Clculo dos servios transportados gravao na tabela SERVTRANS e ETIQUETRAN.

P_CDFILIAL   - Codigo da Filial
P_SERVICOS   - String contendo sequencia de Servios a serem calculados
P_DTINICIAL  - Data inicial
P_DTFINAL    - Data final
P_CDOPERADOR - Cdigo do operador que solicitou o clculo
P_DTHRCALCST - Data/hora do clculo

Para aplicar e debugar
-- @H:\SISTEMAS\DBA\SQL\ORACLE\7191_PLASTP_SERVICOS_TRANSPORTADOS.SQL;
-- @C:\7191_PLASTP_SERVICOS_TRANSPORTADOS.SQL;
-- EXECUTE SERVICOS_TRANSPORTADOS('0032', '005_040_020_050', '01/02/2001', '10/02/2001', '007', TO_DATE('24/01/2001 1119', 'DD/MM/YYYY HH24MI'))
-- SET SERVEROUTPUT ON
-- DBMS_OUTPUT.PUT_LINE('xx');

Criao:
06/03/2001 - Bruno Leonardo de Oliveira

*/

IF EXISTS(SELECT name FROM sysobjects
          WHERE name = 'SERVICOS_TRANSPORTADOS' AND type = 'P')
DROP PROCEDURE SERVICOS_TRANSPORTADOS
GO

CREATE PROCEDURE SERVICOS_TRANSPORTADOS
  (@P_CDFILIAL    VARCHAR(4),
   @P_SERVICOS    VARCHAR(2000),
   @P_DTINICIAL   DATETIME,
   @P_DTFINAL     DATETIME,
   @P_CDOPERADOR  VARCHAR(12),
   @P_DTHRCALCST  DATETIME)
AS
   DECLARE @V_QTCOMESTIPRAT NUMERIC;
   DECLARE @V_QTPADRAO      FLOAT;
   DECLARE @V_QTCONTAI      FLOAT;
   DECLARE @V_QTAMOSTRAUN   FLOAT;
   DECLARE @V_PERCENTUAL    FLOAT;
   DECLARE @V_QTCONTINCOST  FLOAT;
   DECLARE @V_VRARREDTRANS  FLOAT;
   DECLARE @V_QTTOTAPRATST  FLOAT;
   DECLARE @V_QTTOTACONTST  FLOAT;
   DECLARE @V_QTPARCPRATST  FLOAT;
   DECLARE @V_QTCONTCOMPST  FLOAT;
   DECLARE @V_QTTOTAPRATSTCAMOS FLOAT;
   DECLARE @V_QTPARCPRATSTCAMOS FLOAT;
   DECLARE @V_QTTOTACONTSTCAMOS FLOAT;
   DECLARE @V_QTCONTCOMPSTCAMOS FLOAT;
   DECLARE @V_QTCONTINCOSTCAMOS FLOAT;
   DECLARE @V_CDSERVICO     VARCHAR(05);
   DECLARE @V_CDSERVFILI    VARCHAR(05);
   DECLARE @V_CDFILIAL      VARCHAR(4);
   DECLARE @V_NRCARDAPIO    VARCHAR(10);
   DECLARE @V_CDFILAUXPRAT  VARCHAR(4);
   DECLARE @V_CDPRATO       VARCHAR(10);
   DECLARE @V_VRPECONSCARD  NUMERIC;
   DECLARE @V_DTCARDAPIO    DATETIME;
   DECLARE @V_QTCOMESTICAR  NUMERIC;
   DECLARE @V_CDDIETPAD     VARCHAR(4);
   DECLARE @V_QTSUMPERPRAT  NUMERIC;
   DECLARE @V_NRSERVTRAN    VARCHAR(10);
   DECLARE @V_SEQUENCIAL    VARCHAR(10);
   DECLARE @V_CDDESTFILI    VARCHAR(3);
   DECLARE @V_CDCLIENTE     VARCHAR(21);
   DECLARE @V_PRATO         VARCHAR(10);
   DECLARE @V_QTCOMECLIST   NUMERIC;
   DECLARE @V_DIASEMANA     VARCHAR(1);
   DECLARE @V_QTDIAFERI     NUMERIC;
   DECLARE @V_QTCOEST       NUMERIC;
   DECLARE @V_SGUNIDADE     VARCHAR(10);
   DECLARE @V_RECEITA       VARCHAR(2);
BEGIN
   DECLARE C_SERVICO CURSOR FOR
      (SELECT
          SE.CDSERVFILI
       FROM
          SERVICO SE,
          (SELECT SUBSTRING(CDLISTA, 5, 5) AS CDSERVFILI,
						SUBSTRING(CDLISTA, 1, 4) AS CDFILIAL 
				 FROM LISTA 
			   WHERE NRLISTA = @P_SERVICOS) LSER				  
       WHERE
          (SE.CDFILIAL     = @P_CDFILIAL) AND
          (LSER.CDSERVFILI = SE.CDSERVFILI) AND
			 (LSER.CDFILIAL   = SE.CDFILIAL))
   OPEN C_SERVICO;
   FETCH NEXT FROM C_SERVICO INTO @V_CDSERVICO;
   WHILE (@@FETCH_STATUS = 0)
   BEGIN
      DELETE FROM SERVTRAN
      WHERE
         CDFILIAL   = @P_CDFILIAL   AND
         CDSERVFILI = @V_CDSERVICO  AND
         DTSERVTRAN BETWEEN @P_DTINICIAL AND @P_DTFINAL;

      /* REGISTRA O CALCULO NA TABELA DE LOG */
      INSERT INTO LOGSERVTRAN
         (CDFILIAL,
          CDOPERADOR,
          DTHRCALCST,
          CDSERVFILI,
          DTINICIALST,
          DTFINALST)
      VALUES
         (@P_CDFILIAL,
          @P_CDOPERADOR,
          @P_DTHRCALCST,
          @V_CDSERVICO,
          @P_DTINICIAL,
          @P_DTFINAL);

      /* GRAVA A TABELA SERVTRAN E ETIQUETRAN DE ACORDO COM OS CARDPIOS */
      DECLARE C_CARDAPIO CURSOR FOR
         (SELECT
             CO.CDFILIAL,
             CO.NRCARDAPIO,
             CO.CDFILAUXPRAT,
             CO.CDPRATO,
             CO.VRPECONSCARD,
             CA.CDSERVFILI,
             CA.DTCARDAPIO,
             CA.QTCOMESTICAR,
             ISNULL(CA.CDDIETPAD,'XXXX') AS CDDIETPAD,
             ISNULL(PT.VRARREDTRANS, 0) AS VRARREDTRANS,
             PT.SGUNIDADE
          FROM
             COMPCARD CO,
             CARDADIA CA,
             PRATO PT
          WHERE
             (CA.CDFILIAL   = @P_CDFILIAL)                       AND
             (CA.CDSERVFILI = @V_CDSERVICO)                      AND
             (CA.DTCARDAPIO BETWEEN @P_DTINICIAL AND @P_DTFINAL) AND
             (CO.CDFILIAL   = CA.CDFILIAL)                       AND
             (CO.NRCARDAPIO = CA.NRCARDAPIO)                     AND
             (CO.CDPRATO    = PT.CDPRATO)                        AND
             (CO.CDFILAUXPRAT = PT.CDFILAUXPRAT))
      OPEN C_CARDAPIO;
      FETCH NEXT FROM C_CARDAPIO INTO @V_CDFILIAL,
                                      @V_NRCARDAPIO,
                                      @V_CDFILAUXPRAT,
                                      @V_CDPRATO,
                                      @V_VRPECONSCARD,
                                      @V_CDSERVFILI,
                                      @V_DTCARDAPIO,
                                      @V_QTCOMESTICAR,
                                      @V_CDDIETPAD,
                                      @V_VRARREDTRANS,
                                      @V_SGUNIDADE;
      WHILE (@@FETCH_STATUS = 0)
      BEGIN
         SET @V_DIASEMANA = CONVERT(VARCHAR, DATEPART(DW, @V_DTCARDAPIO));
         SET @V_QTDIAFERI = 0;

         SELECT
            @V_QTDIAFERI = COUNT(*)
         FROM
            FERIFILI
         WHERE
            CDFILIAL   = @P_CDFILIAL AND
            DTFERIFILI = @V_DTCARDAPIO;

         IF (@V_QTDIAFERI = 1) BEGIN
            SET @V_DIASEMANA = 8;
         END;

         DECLARE C_DESTINO CURSOR FOR
            (SELECT
                D.CDCLIENTE,
                D.CDDESTFILI,
                CASE @V_DIASEMANA
                   WHEN '1' THEN D.QTCOESTCSDOM
                   WHEN '2' THEN D.QTCOESTCSSEG
                   WHEN '3' THEN D.QTCOESTCSTER
                   WHEN '4' THEN D.QTCOESTCSQUA
                   WHEN '5' THEN D.QTCOESTCSQUI
                   WHEN '6' THEN D.QTCOESTCSSEX
                   WHEN '7' THEN D.QTCOESTCSSAB
                   WHEN '8' THEN D.QTCOESTCSFER
                 END AS V_QTCOEST
             FROM
                DESTSRVCLI D
             WHERE
                D.CDFILIAL   = @P_CDFILIAL   AND
                D.CDSERVFILI = @V_CDSERVFILI AND
                NOT EXISTS(SELECT
                     C.CDFILIAL
                  FROM
                     CARDACLI CC,
                     CARDADIA C
                  WHERE
                     C.CDFILIAL   = @P_CDFILIAL   AND
                     C.CDSERVFILI = @V_CDSERVFILI AND
                     C.DTCARDAPIO = @V_DTCARDAPIO AND
                     C.CDFILIAL   = CC.CDFILIAL   AND
                     C.NRCARDAPIO = CC.NRCARDAPIO)

             UNION ALL

             SELECT
                CC.CDCLIENTE,
                CC.CDDESTFILI,
                CC.QTCOMESTICLI AS V_QTCOEST
             FROM
                CARDACLI CC,
                CARDADIA C
             WHERE
                C.CDFILIAL   = @P_CDFILIAL   AND
                C.CDSERVFILI = @V_CDSERVFILI AND
                C.DTCARDAPIO = @V_DTCARDAPIO AND
                C.CDFILIAL   = CC.CDFILIAL   AND
                C.NRCARDAPIO = CC.NRCARDAPIO)
         OPEN C_DESTINO;
         FETCH NEXT FROM C_DESTINO INTO @V_CDCLIENTE,
                                        @V_CDDESTFILI,
                                        @V_QTCOEST;
         WHILE (@@FETCH_STATUS = 0)
         BEGIN
            SELECT
               @V_PRATO = MAX(S.CDPRATO)
            FROM
               SERVTRAN S
            WHERE
               (S.CDFILIAL     = @P_CDFILIAL)     AND
               (S.CDSERVFILI   = @V_CDSERVFILI)   AND
               (S.DTSERVTRAN   = @V_DTCARDAPIO)   AND
               (S.CDFILAUXPRAT = @V_CDFILAUXPRAT) AND
               (S.CDPRATO      = @V_CDPRATO)      AND
               (S.CDDESTFILI   = @V_CDDESTFILI)   AND
               (S.CDCLIENTE    = @V_CDCLIENTE);

            IF (@V_PRATO IS NULL) BEGIN
               SET @V_QTCOMECLIST   = @V_QTCOEST;
               SET @V_QTCOMESTIPRAT = (@V_VRPECONSCARD / 100 * @V_QTCOEST);

               SELECT
                  @V_RECEITA = MAX(R.RECEITA)
               FROM
                 (SELECT
                     'RS' AS RECEITA /*RECEITA POR SERVIO*/
                  FROM
                     RECESERV
                  WHERE
                     CDFILIAL     = @V_CDFILIAL     AND
                     CDSERVFILI   = @V_CDSERVFILI   AND
                     CDPRATO      = @V_CDPRATO      AND
                     CDFILAUXPRAT = @V_CDFILAUXPRAT

                  UNION

                  SELECT
                     'RL' AS RECEITA /*RECEITA LOCAL*/
                  FROM
                     RECEFILI RF
                  WHERE
                     RF.CDFILIAL     = @V_CDFILIAL     AND
                     RF.CDPRATO      = @V_CDPRATO      AND
                     RF.CDFILAUXPRAT = @V_CDFILAUXPRAT AND
                     NOT EXISTS (SELECT
                                    RS.CDPRATO
                                 FROM
                                    RECESERV RS
                                 WHERE
                                    RS.CDFILIAL     = RF.CDFILIAL   AND
                                    RS.CDSERVFILI   = @V_CDSERVFILI AND
                                    RS.CDPRATO      = RF.CDPRATO    AND
                                    RS.CDFILAUXPRAT = RF.CDFILAUXPRAT)

                  UNION

                  SELECT
                     'RP' AS RECEITA /*RECEITA PADRO*/
                  FROM
                     RECEPADR RP
                  WHERE
                     RP.CDPRATO      = @V_CDPRATO AND
                     RP.CDFILAUXPRAT = @V_CDFILAUXPRAT AND
                     NOT EXISTS (SELECT
                                    RS.CDPRATO
                                 FROM
                                    RECESERV RS
                                 WHERE
                                    RS.CDFILIAL     = @V_CDFILIAL   AND
                                    RS.CDSERVFILI   = @V_CDSERVFILI AND
                                    RS.CDPRATO      = RP.CDPRATO       AND
                                    RS.CDFILAUXPRAT = RP.CDFILAUXPRAT) AND
                     NOT EXISTS (SELECT
                                    RF.CDPRATO
                                 FROM
                                    RECEFILI RF
                                 WHERE
                                    RF.CDFILIAL     = @V_CDFILIAL AND
                                    RF.CDPRATO      = RP.CDPRATO      AND
                                    RF.CDFILAUXPRAT = RP.CDFILAUXPRAT)) R

               SET @V_QTPADRAO    = NULL;
               SET @V_QTCONTAI    = NULL;
               SET @V_QTAMOSTRAUN = NULL;
               SET @V_PERCENTUAL  = NULL;

               IF @V_RECEITA = 'RS' BEGIN
                  SELECT
                     @V_QTPADRAO    = MAX(QTPADRAOSERV),
                     @V_QTCONTAI    = MAX(QTCONTAISERV),
                     @V_QTAMOSTRAUN = MAX(QTAMOSTRSERV),
                     @V_PERCENTUAL  = MAX(VRPEMINSERV)
                  FROM
                     PRATSERV
                  WHERE
                     CDFILIAL     = @V_CDFILIAL   AND
                     CDSERVFILI   = @V_CDSERVFILI AND
                     CDPRATO      = @V_CDPRATO    AND
                     CDFILAUXPRAT = @V_CDFILAUXPRAT;
               END ELSE BEGIN
                  IF @V_RECEITA = 'RL' BEGIN
                     SELECT
                        @V_QTPADRAO    = MAX(QTPADRAOFILI),
                        @V_QTCONTAI    = MAX(QTCONTAIFILI),
                        @V_QTAMOSTRAUN = MAX(QTAMOSTRFILI),
                        @V_PERCENTUAL  = MAX(VRPEMINFILI)
                     FROM
                        PRATFILI
                     WHERE
                        CDFILIAL     = @V_CDFILIAL AND
                        CDPRATO      = @V_CDPRATO  AND
                        CDFILAUXPRAT = @V_CDFILAUXPRAT;
                  END ELSE BEGIN
                     IF @V_RECEITA = 'RP' BEGIN
                        SELECT
                           @V_QTPADRAO    = MAX(QTPADRAOPRAT),
                           @V_QTCONTAI    = MAX(QTCONTAIPRAT),
                           @V_QTAMOSTRAUN = MAX(QTAMOSTRPADR),
                           @V_PERCENTUAL  = MAX(VRPEMINPADR)
                        FROM
                           PRATPADR
                        WHERE
                           CDPRATO      = @V_CDPRATO AND
                           CDFILAUXPRAT = @V_CDFILAUXPRAT;
                     END;
                  END;
               END;

               /* BUSCA A QUANTIDADE DE AMOSTRAS PADRO*/
               IF @V_QTAMOSTRAUN IS NULL BEGIN
                  SELECT
                     @V_QTAMOSTRAUN = MAX(QTAMOSTRAUN)
                  FROM
                     UNIDMEDIFILI
                  WHERE
                     CDFILIAL  = @V_CDFILIAL AND
                     SGUNIDADE = @V_SGUNIDADE;
                  IF @V_QTAMOSTRAUN IS NULL BEGIN
                     SET @V_QTAMOSTRAUN = 0;
                  END;
               END;

               IF @V_PERCENTUAL IS NULL BEGIN
                  SELECT
                     @V_PERCENTUAL = MAX(VRPEMINCONT)
                  FROM
                     PARAMPLANEJA
                  WHERE
                     CDFILIAL = @V_CDFILIAL;
                  IF @V_PERCENTUAL IS NULL BEGIN
                     SET @V_PERCENTUAL = 0;
                  END;
               END;

               IF ((NOT ((@V_QTPADRAO IS NULL) OR (@V_QTPADRAO = 0))) AND
                   (NOT ((@V_QTCONTAI IS NULL) OR (@V_QTCONTAI = 0)))) BEGIN

                  /* ==== CLCULO SEM amostra ============================ */
                  SET @V_QTTOTAPRATST = 0;
                  SET @V_QTPARCPRATST = 0; /*QUANTIDADE DO CONTAINER INCOMPLETO*/
                  SET @V_QTTOTACONTST = 0; /*TOTAL DE CONTAINERS*/
                  SET @V_QTCONTCOMPST = 0; /*TOTAL DE CONTAINERS COMPLETOS*/
                  SET @V_QTCONTINCOST = 0; /*TOTAL DE CONTAINERS INCOMPLETOS*/

                  SET @V_QTTOTAPRATST = ROUND((@V_QTPADRAO * @V_QTCOMESTIPRAT), 5);

                  IF (@V_VRARREDTRANS <> 0) BEGIN
                     IF (@V_QTTOTAPRATST > 0) AND (@V_QTTOTAPRATST - (FLOOR(@V_QTTOTAPRATST/@V_VRARREDTRANS)* @V_VRARREDTRANS) > 0) BEGIN
                         SET @V_QTTOTAPRATST = (FLOOR(@V_QTTOTAPRATST/@V_VRARREDTRANS) + 1) * @V_VRARREDTRANS;
                     END;
                  END;

                  /*CLCULO PARA VERIFICAR A QUANTIDADE DE CONTAINERS COMPLETOS E INCOMPETOS*/
                  IF @V_QTTOTAPRATST >= @V_QTCONTAI BEGIN
                     SET @V_QTPARCPRATST = @V_QTTOTAPRATST - (FLOOR(@V_QTTOTAPRATST / @V_QTCONTAI) * @V_QTCONTAI);
                     SET @V_QTTOTACONTST = FLOOR(@V_QTTOTAPRATST / @V_QTCONTAI);
                     SET @V_QTCONTCOMPST = @V_QTTOTACONTST;

                     IF @V_QTPARCPRATST > 0 BEGIN
                        SET @V_QTCONTINCOST = 1;
                        SET @V_QTTOTACONTST = @V_QTTOTACONTST + 1;

                        IF @V_PERCENTUAL > 0 BEGIN
                           IF @V_QTPARCPRATST < ((@V_PERCENTUAL / 100) * @V_QTCONTAI) BEGIN
                              SET @V_QTPARCPRATST = (@V_QTCONTAI + @V_QTPARCPRATST) / 2;
                              SET @V_QTCONTINCOST = 2;
                              SET @V_QTCONTCOMPST = @V_QTCONTCOMPST - 1;
                           END;
                        END;
                     END;
                  END
                  ELSE BEGIN
                     SET @V_QTPARCPRATST = @V_QTTOTAPRATST;
                     SET @V_QTTOTACONTST = 1;
                     SET @V_QTCONTCOMPST = 0;
                     SET @V_QTCONTINCOST = 1;
                  END;
                  /* === FIM CLCULO SEM AMOSTRA ============================ */

                  /* ==== CLCULO COM amostra ============================ */
                  SET @V_QTTOTAPRATSTCAMOS = 0; /*QUANTIDADE TOTAL com amostras*/
                  SET @V_QTPARCPRATSTCAMOS = 0; /*QUANTIDADE DO CONTAINER INCOMPLETO com amostras*/
                  SET @V_QTTOTACONTSTCAMOS = 0; /*TOTAL DE CONTAINERS com amostras*/
                  SET @V_QTCONTCOMPSTCAMOS = 0; /*TOTAL DE CONTAINERS COMPLETOS com amostras*/
                  SET @V_QTCONTINCOSTCAMOS = 0; /*TOTAL DE CONTAINERS INCOMPLETOS com amostras*/

                  SET @V_QTTOTAPRATSTCAMOS = @V_QTTOTAPRATST + @V_QTAMOSTRAUN;

                  /*CLCULO PARA VERIFICAR A QUANTIDADE DE CONTAINERS COMPLETOS E INCOMPETOS*/
                  IF @V_QTTOTAPRATSTCAMOS >= @V_QTCONTAI BEGIN
                     SET @V_QTPARCPRATSTCAMOS = @V_QTTOTAPRATSTCAMOS - (FLOOR(@V_QTTOTAPRATSTCAMOS / @V_QTCONTAI) * @V_QTCONTAI);
                     SET @V_QTTOTACONTSTCAMOS = FLOOR(@V_QTTOTAPRATSTCAMOS / @V_QTCONTAI);
                     SET @V_QTCONTCOMPSTCAMOS = @V_QTTOTACONTSTCAMOS;

                     IF @V_QTPARCPRATSTCAMOS > 0 BEGIN
                        SET @V_QTCONTINCOSTCAMOS = 1;
                        SET @V_QTTOTACONTSTCAMOS = @V_QTTOTACONTSTCAMOS + 1;

                        IF @V_PERCENTUAL > 0 BEGIN
                           IF @V_QTPARCPRATSTCAMOS < ((@V_PERCENTUAL / 100) * @V_QTCONTAI) BEGIN
                              SET @V_QTPARCPRATSTCAMOS = (@V_QTCONTAI + @V_QTPARCPRATSTCAMOS) / 2;
                              SET @V_QTCONTINCOSTCAMOS = 2;
                              SET @V_QTCONTCOMPSTCAMOS = @V_QTCONTCOMPSTCAMOS - 1;
                           END;
                        END;
                     END;
                  END
                  ELSE BEGIN
                     SET @V_QTPARCPRATSTCAMOS = @V_QTTOTAPRATSTCAMOS;
                     SET @V_QTTOTACONTSTCAMOS = 1;
                     SET @V_QTCONTCOMPSTCAMOS = 0;
                     SET @V_QTCONTINCOSTCAMOS = 1;
                  END;
                  /* === FIM CLCULO COM AMOSTRA ============================ */

                 /*************************************************************************/

                  IF ((@V_QTCOMESTIPRAT = 0) OR (@V_QTCOMESTIPRAT IS NULL)) BEGIN
                     SET @V_QTSUMPERPRAT = 0;
                  END ELSE BEGIN
                     SET @V_QTSUMPERPRAT = ((100 * @V_QTCOMESTIPRAT) / @V_QTCOMESTICAR);
                  END;

          /*----------- Gera o sequencial da tabela dos servios transportados---------*/

                  SELECT
                     @V_NRSERVTRAN = MAX(NRSERVTRAN)
                  FROM
                     SERVTRAN
                  WHERE
                     (CDFILIAL   = @P_CDFILIAL)   AND
                     (CDSERVFILI = @V_CDSERVFILI);

                  IF (@V_NRSERVTRAN IS NULL) BEGIN
                     SET @V_SEQUENCIAL = '0000000001';
                  END
                  ELSE BEGIN
                     SET @V_SEQUENCIAL = RIGHT(REPLICATE('0', 10) + (CONVERT(VARCHAR,(CONVERT(NUMERIC, @V_NRSERVTRAN) + 1))), 10);
                  END;

                  INSERT INTO SERVTRAN
                     (CDFILIAL,
                      CDSERVFILI,
                      DTSERVTRAN,
                      NRSERVTRAN,
                      CDDESTFILI,
                      CDCLIENTE,
                      CDFILAUXPRAT,
                      CDPRATO,
                      QTTOTAPRATST,
                      QTPARCPRATST,
                      QTTOTACONTST,
                      QTCONTCOMPST,
                      VRPECONSST,
                      QTPADRAOST,
                      QTCONTAIST,
                      CDDIETPADST,
                      QTCOMESTIST,
                      QTCOMECLIST,
                      QTAMOSTRAST,
                      QTTOTACONTSTCAMOS,
                      QTCONTCOMPSTCAMOS)
                   VALUES
                      (@V_CDFILIAL,
                       @V_CDSERVFILI,
                       @V_DTCARDAPIO,
                       @V_SEQUENCIAL,
                       @V_CDDESTFILI,
                       @V_CDCLIENTE,
                       @V_CDFILAUXPRAT,
                       @V_CDPRATO,
                       @V_QTTOTAPRATST,
                       @V_QTPARCPRATST,
                       @V_QTTOTACONTST,
                       @V_QTCONTCOMPST,
                       @V_QTSUMPERPRAT,
                       @V_QTPADRAO,
                       @V_QTCONTAI,
                       @V_CDDIETPAD,
                       @V_QTCOMESTIPRAT,
                       @V_QTCOMECLIST,
                       @V_QTAMOSTRAUN,
                       @V_QTTOTACONTSTCAMOS,
                       @V_QTCONTCOMPSTCAMOS);

                  EXEC GERA_ETIQUETRAN @V_CDFILIAL,   @V_CDSERVFILI,        @V_CDDIETPAD,  @V_CDDESTFILI,
                                       @V_SEQUENCIAL, @V_CDCLIENTE,         @V_DTCARDAPIO, @V_CDFILAUXPRAT,
                                       @V_CDPRATO,    @V_QTCONTCOMPSTCAMOS, @V_QTCONTAI,   @V_QTCONTINCOSTCAMOS,
                                       @V_QTPARCPRATSTCAMOS;
               END;
            END;
            FETCH NEXT FROM C_DESTINO INTO @V_CDCLIENTE,
                                           @V_CDDESTFILI,
                                           @V_QTCOEST;

         END;
         CLOSE C_DESTINO;
         DEALLOCATE C_DESTINO;
         FETCH NEXT FROM C_CARDAPIO INTO @V_CDFILIAL, @V_NRCARDAPIO, @V_CDFILAUXPRAT,
                                         @V_CDPRATO, @V_VRPECONSCARD, @V_CDSERVFILI,
                                         @V_DTCARDAPIO, @V_QTCOMESTICAR, @V_CDDIETPAD,
                                         @V_VRARREDTRANS, @V_SGUNIDADE;
      END;
      CLOSE C_CARDAPIO;
      DEALLOCATE C_CARDAPIO;
      FETCH NEXT FROM C_SERVICO INTO @V_CDSERVICO;
   END;
   CLOSE C_SERVICO;
   DEALLOCATE C_SERVICO;
END;


-- VERSAO --
EXEC ATUVEROBJ 'SERVICOS_TRANSPORTADOS','4.11.135';
GO
