function crm00016000_Mapa_de_Prospeccao_Controller(CRM_Utilities, ScreenService, templateManager, General) {
    
    this.widgetOnEnterOnce = function(widget, fieldsToApply) {
        
        var partInfoController = CRM_Utilities.getController('PartnerInfosModalController');
        
        var filterRow = {};
        var wdgt = templateManager.container.getWidget('WDGT_PARCEIRO_NEGOCIO');
        
        if((typeof templateManager !== 'undefined') && templateManager.LOGGEDOPERATOR) {
            filterRow.CDOPERRESPONSAVEL = [templateManager.LOGGEDOPERATOR.CDOPERADOR];
            
            if(widget.name === 'WDGT_PARCEIRO_NEGOCIO' )
                CRM_Utilities.openFilterOnEnter(widget, filterRow, fieldsToApply);
            else{
                widget.dataSource.data = wdgt.dataSource.data;
                widget.appliedFilter = wdgt.appliedFilter;
            }
        }
        
        this.setResaleRules(widget, false);
        CRM_Utilities.cascadeReadOnly(widget, ['SGESTADO', 'CDMUNICIPIO']);
        CRM_Utilities.setObjectFilterWhenResaleLoggedOperator(widget);
        partInfoController.setModalWidgetOnActiveWidget(widget, 'NRPARCNEGOCIO')
    };
    
    this.setResaleRules = function(widget, reload = true) {

        var loggedOperatorInfos = CRM_Utilities.getLoggedOperatorInfos();

        if (loggedOperatorInfos.IDTPOPERADOR === 'R' && Boolean(loggedOperatorInfos.NRREVENDA)) {

            var restrictObjects = [];

            restrictObjects.push(widget.getField("NMOPERREAL"));
            restrictObjects.push(widget.getField("CDOPERREAL"));
            restrictObjects.push(widget.getField("NMPARCNEGOCIO"));
            restrictObjects.push(widget.getField("NRPARCNEGOCIO"));

            var taskTransferWidget = templateManager.container.getWidget("TRANSFERIR");
            restrictObjects.push(taskTransferWidget.getField("NMOPERREAL"));

            var evolutionWidget = templateManager.container.getWidget("evolucao");
            restrictObjects.push(evolutionWidget.getField("NMOPERADORREAL"));

            CRM_Utilities.setResaleRulesInRestrictObjectsByLoggedOperatorResale(restrictObjects);

        }
        
        if (reload) {
            widget.reload();
        }
    };
    
    /**
     * Função para setar os valores dos filtros da widget
     * de 'Interlorutores', depois que o usuário selecionar
     * um parceiro.
     * 
     * @param {object} widget widget de 'Parceiros'.
    */
    this.setInterlocutorWidgetFilter = function(widget) {
        
        var interlocutorWidgetIndex = CRM_Utilities.getWidgetPosition(widget.widgets, "WDGT_INTERLUCUTOR_PARCEIRO");
        var interlocutorWidget = widget.widgets[interlocutorWidgetIndex];
        
        var widgetFilter = interlocutorWidget.dataSourceFilter;
        var partnerWidgetCurrentRow = interlocutorWidget.getParent().currentRow;
        
        /*Erro de nomeclaturo no dataSource, o minemônico 'P_PARCREVEBDA' referencia ao NRPARCNEGOCIO
        do parceiro em caso*/
        var parcnegocioFilterIndex = CRM_Utilities.getFilterPosition(widgetFilter, "P_PARCREVENDA");
        var nrorgFilterIndex = CRM_Utilities.getFilterPosition(widgetFilter, "P_NRORG");
        
        widgetFilter[parcnegocioFilterIndex].value = partnerWidgetCurrentRow.NRPARCNEGOCIO;
        widgetFilter[nrorgFilterIndex].value = partnerWidgetCurrentRow.NRORG;
        
        interlocutorWidget.reload();
        
    };
    
    /**
     * Função para setar os valores dos filtros da widget
     * de 'Evoluções', depois que o usuário selecionar
     * um parceiro.
     * 
     * @param {object} widget widget de 'Parceiros'.
    */
    this.setEvolutionWidgetFilter = function(widget) {
        
        var evolutionWidget = widget;
        
        var widgetFilter = evolutionWidget.dataSourceFilter;
        var partnerWidgetCurrentRow = evolutionWidget.parent.parent.currentRow;
        
        var nrseqcontatoFilterIndex = CRM_Utilities.getFilterPosition(widgetFilter, "P_NRPARCNEGOCIO");
        
        widgetFilter[nrseqcontatoFilterIndex].value = partnerWidgetCurrentRow.NRPARCNEGOCIO;
        
        evolutionWidget.reload();
        
    };
    
    /**
     * Função para disparar os eventos relacionados 
     * a widget de parceiros logo após um parceiro
     * ser selecionado.
     * 
     * @param {object} widget widget de parceiros.
    */
    this.partnerWidgetAfterMoveRow = function(widget) {
        
        //this.setInterlocutorWidgetFilter(widget);
        
        this.setEvolutionWidgetFilter(widget);
        
    };
    
    /**
     * Função para mudar o label da action para leads e prospects.
     * 
     * @param {object} widget widget de parceiros.
    */
    this.setActionOpenWindowLabel = function(widget) {
        
        var currentRow = widget.currentRow;
        var isLeadOrProspect = widget.currentRow.NMTIPOPARCEIRO.toLowerCase();
        
        widget.actions.forEach(function(action) {
            if(action.name === "OPEN_LEAD_OR_PROSPECT")
                action.label = 'Trabalhar '+CRM_Utilities.capitalizeFirstLetter(isLeadOrProspect);
        });
        
    };
    
    /**
     * Função para abrir a tela de lead/prospect do parceiro
     * selecionado.
     * 
     * @param {object} widget widget de parceiros.
    */
    this.openWindowLeadOrProspect = function(widget) {
           
        var isLeadOrProspect = widget.currentRow.TIPO;
        var windowToOpen     = '';
        var widgetToFilter   = '';
        widget.currentRow.NMTIPO = widget.currentRow.NMTIPOPARCEIRO;
        
        if(isLeadOrProspect === "CANDIDATO") {
            windowToOpen   = 'crm00040_000_leads';
            widgetToFilter = 'gridLead';
        }else if(isLeadOrProspect === "PROSPECT") {
            windowToOpen   = 'ger45000_prospect';
            widgetToFilter = 'gridProspect';
        }else {
            windowToOpen   = 'crm_parceiro_negocio';
            widgetToFilter = 'parceiroNegocio';    
            widget.currentRow.NMTIPO = 'Parceiro';
        }
       
        ScreenService.confirmMessage('Deseja ir para a tela de '+widget.currentRow.NMTIPO+'?', 'CONFIRMATION',
        function(success) {
            ScreenService.openWindow('product#'+windowToOpen).then(function() {
                    var tipoOperador = templateManager.LOGGEDOPERATOR.IDTPOPERADOR || 'E';
                    widgetToFilter = templateManager.container.getWidget(widgetToFilter);
                    var filter = [
                        {
                            name : "NRPARCNEGOCIO",
                            operator : "=",
                            static : true,
                            value : widget.currentRow.NRPARCNEGOCIO
                        },
                        {
                            name: "NRORG",
                            operator: "=",
                            static: true,
                            value: getLocalVar('CRM_NRORG')
                        },
                        {
                            name: "IDTPOPERADOR",
                            operator: "=",
                            static: true,
                            value: tipoOperador
                        }
                    ]; 
                    
                    if(windowToOpen == 'ger45000_prospect') {
                        filter.push(
                            {
                                name: "NRPARCRESPROSP",
                                operator: "=",
                                static: true,
                                value: widget.currentRow.NRPARCRESPONSAVEL
                            }
                        );
                    }
                    
                    widgetToFilter.dataSourceFilter = filter;
                    widgetToFilter.fromMap = true;
                    widgetToFilter.reload().
                      then(function() {
                        ScreenService.closePopup(true);
                        widgetToFilter.reload();
                    });
              });
        });
    };
    
    
    /**
     * Função para abrir a tela de tarefas do parceiro
     * selecionado.
     * 
     * @param {object} widget widget de parceiros.
    */
    this.openWindowTask = function(widget) {
        ScreenService.confirmMessage('Deseja ir para a agenda de tarefas?', 'CONFIRMATION',
        function(success) {
            ScreenService.openWindow('product#crm31000_000_agenda_de_tarefas').
              then(function() {
                    var widgetToFilter = templateManager.container.getWidget('Agenda');
                    var filter = [
                        {
                            name : "NRPARCNEGOCIO",
                            operator : "IN",
                            value : [widget.parent.parent.currentRow.NRPARCNEGOCIO]
                        },
                        {
                            name: "NRORG",
                            operator: "=",
                            value: "@getLocalVar('CRM_NRORGTRAB')@"
                        },
                        {
                            name: "CRM_NRORGTRAB",
                            operator: "=",
                            value: "@getLocalVar('CRM_NRORGTRABALHO')@"
                        }
                    ]; 
                    
                    widgetToFilter.dataSourceFilter = filter;
                    widgetToFilter.customFilter = true;
                    widgetToFilter.reload().
                      then(function() {
                        ScreenService.closePopup(true);
                    });
              });
        });
    };
    
     /**
     * Função para abrir a oportunidade do parceiro
     * selecionado.
     * 
     * @param {object} widget widget de parceiros.
    */
    this.openWindowOport = function(widget) {
        ScreenService.confirmMessage('Deseja ir para a tela de oportunidades?', 'CONFIRMATION',
        function(success) {
            ScreenService.openWindow('product#crm00002_001_oportunidade_de_negocio').
              then(function() {
                    var widgetToFilter = templateManager.container.getWidget('oportunidadegrid');
                    var filter = [{
                        name : "NRSEQOPORT",
                        operator : "IN",
                        value : [widget.currentRow.NRSEQOPORT]
                    }]; 
                    
                    widgetToFilter.dataSourceFilter = filter;
                    widgetToFilter.reload().
                      then(function() {
                        ScreenService.closePopup(true);
                    });
              });
        });
    };
    
      /**
     * Função para abrir os compromissos do parceiro
     * selecionado.
     * 
     * @param {object} widget widget de parceiros.
    */
    this.openWindowCommit = function(widget) {
        ScreenService.confirmMessage('Deseja ir para a tela de compromissos?', 'CONFIRMATION',
        function(success) {
            ScreenService.openWindow('product#crm30000_000_compromissos').
              then(function() {
                    var widgetToFilter = templateManager.container.getWidget('CALENDARIO');
                    var filter = [{
                        name : "NRPARCNEGOCIO",
                        operator : "IN",
                        value : [widget.parent.parent.currentRow.NRPARCNEGOCIO]
                    }]; 
                    
                    widgetToFilter.dataSourceFilter = filter;
                    widgetToFilter.reload().
                      then(function() {
                        ScreenService.closePopup(true);
                        widgetToFilter.reload();
                    });
              });
        });
    };
    
    this.unMaskPhone = function(widget) {
        widget.dataSourceFilter.forEach(function(filter) {
            if(filter.name === "TELEFONE") {
                filter.value = filter.value.replace(/[^0-9]/g, '');
                filter.value = '%' + filter.value + '%'; 
                
            }
        });
    };
    
    this.reloadTab = function(widget) {
        if(widget.currentFilter && widget.currentFilter !== General.getFieldValue('NRPARCNEGOCIO', 'WDGT_PARCEIRO_NEGOCIO'))
            widget.reload();
        else if(!widget.currentFilter)
            widget.reload();
        
        this.setCurrentFilter(widget);    
    };
    
    this.setCurrentFilter = function(widget) {
        widget.currentFilter = General.getFieldValue('NRPARCNEGOCIO', 'WDGT_PARCEIRO_NEGOCIO');    
    };
    
    this.alteraMunicipioFilter = function(widget) {
        var estado    = widget.getField('SGESTADO');
        var municipio = widget.getField('CDMUNICIPIO');
        
        var estadoFilter = CRM_Utilities.getComponentDataSourceFilter(municipio, 'SGESTADO');
        
        if(Util.isEmptyOrBlank(estado.value())) {
            estadoFilter.value = '';
        }else{
            estadoFilter.value = estado.value();
        }
    };
    
    this.alteraEstadoFilter = function(widget){
        var estado    = widget.getField('SGESTADO');
        var municipio = widget.getField('CDMUNICIPIO');
        var pais = widget.getField('CDPAIS');
        
        var estadoFilter = CRM_Utilities.getComponentDataSourceFilter(estado, 'CDPAIS');
        var municipioFilter = CRM_Utilities.getComponentDataSourceFilter(municipio, 'CDPAIS');
        
        if(Util.isEmptyOrBlank(pais.value())){
            municipioFilter.value = '';
            estadoFilter.value = '';
        }else{
            municipioFilter.value = pais.value();
            estadoFilter.value = pais.value();
        }
    };
}

Configuration(function (ContextRegister) {
    ContextRegister.register("crm00016000_Mapa_de_Prospeccao_Controller", crm00016000_Mapa_de_Prospeccao_Controller);
});
